@@ -35,15 +35,19 @@ class Network3Medusa():
             print("File size according to `FileInfoQuery`: ", info.size)
         else:
             size = 6000
-            chunks = [str[i:i+n] for i in range (0, len(raw_json), size)]
+            chunks = [raw_json[i:i+size] for i in range (0, len(raw_json), size)]
+            first = True
             for chunk in chunks:
-                print(chunk)
-            # self.add_file_to_hedera(raw_json)
-            # if WEBEX_ROOM:
-            #     self.send_webex_notification()
-            # query = FileInfoQuery().setFileId(self.fileId)
-            # info = query.execute(self.client)
-            # print("File size according to `FileInfoQuery`: ", info.size)            
+                if first == True:
+                    first = False
+                    self.add_file_to_hedera(chunk)            
+                else:
+                    self.append_file_to_hedera(chunk)           
+            if WEBEX_ROOM:
+                self.send_webex_notification()
+            query = FileInfoQuery().setFileId(self.fileId)
+            info = query.execute(self.client)
+            print("File size according to `FileInfoQuery`: ", info.size)            
     def py2output(self):
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
 
